@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: index.php,v 1.12 2005/04/12 03:47:13 tohokuaiki Exp $
+ * $Id: index.php,v 1.19 2005/11/07 07:32:58 tohokuaiki Exp $
  * Copyright (c) 2003 by Jeremy N. Cowgar <jc@cowgar.com>
  * Copyright (c) 2003 by Hiro SAKAI (http://wellwine.zive.net/)
  *
@@ -24,7 +24,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
  */
 
-include('header.php');
+include_once('header.php');
 include_once(sprintf('%s/modules/%s/class/class.weblog.php', XOOPS_ROOT_PATH, $xoopsModule->dirname()));
 include_once(sprintf('%s/modules/%s/class/class.weblogcategories.php', XOOPS_ROOT_PATH, $xoopsModule->dirname()));
 
@@ -45,6 +45,16 @@ function getAllChildrenCount($currentuid, $cat_id, $user_id=0) {
 $user_id = !empty($_GET['user_id']) ? intval($_GET['user_id']) : 0;
 $start = !empty($_GET['start']) ? intval($_GET['start']) : 0;
 $cat_id = !empty($_GET['cat_id']) ? intval($_GET['cat_id']) : 0;
+$date = !empty($_GET['date']) ? intval($_GET['date']) : 0;	// unixtime (archive.php is YYYYMM)
+
+// privilege check
+include_once(sprintf('%s/modules/%s/include/privilege.inc.php', XOOPS_ROOT_PATH, $xoopsModule->dirname())) ;
+$isAdmin = ( isset($xoopsUser) && is_object($xoopsUser) ) ? $xoopsUser->isAdmin($xoopsModule->mid()) : false ;
+if( ! $isAdmin && ! checkprivilege( "read_index" , $xoopsModule->dirname() , $cat_id ) ){
+    redirect_header(sprintf('%s/index.php', XOOPS_URL ),
+                    5, _BL_CANNOT_READ_SORRY);
+    exit();
+}
 
 // obtain configuration parameters
 $perPage = $xoopsModuleConfig['numperpage'];
@@ -52,15 +62,17 @@ $perPage = $xoopsModuleConfig['numperpage'];
 // Determine the user we are retrieving the blog entries for
 if (is_object($xoopsUser)) {
     $currentUser = $xoopsUser;
+	$useroffset = $xoopsUser->timezone() - $xoopsConfig['server_TZ'] ;
 } else {
     $currentUser =& new XoopsUser();
     $currentUser->setVar('uid', 0);
+	$useroffset = $xoopsConfig['default_TZ'] - $xoopsConfig['server_TZ'] ; ;
 }
 $isAdmin = $currentUser->isAdmin($xoopsModule->mid());
 $currentuid = $currentUser->getVar('uid');
 
 // specify template
-$xoopsOption['template_main'] = 'weblog_entries.html';
+$xoopsOption['template_main'] = 'weblog'.$mydirnumber.'_entries.html';
 
 // obtain class instances
 $myts =& MyTextSanitizer::getInstance();
@@ -85,41 +97,59 @@ if ($xoopsModuleConfig['update_reads_when'] == 2 && $user_id > 0 ||
 
 // obtain row count
 //$count = $weblog->getCountByUser($currentuid, $user_id);
-$count = $weblog->getCountByCategory($currentuid, $cat_id, $user_id);
+//$count = $weblog->getCountByCategory($currentuid, $cat_id, $user_id);
+$count = $weblog->getCountByDate($currentuid, $cat_id, $user_id , $date, $useroffset);
 
 // obtain entries
 //$result =& $weblog->getEntries($currentuid, $user_id, $start, $perPage);
-$result =& $weblog->getEntriesByCategory($currentuid, $cat_id, $user_id, $start, $perPage);
+if( empty($date) ){
+	$weblog_result =& $weblog->getEntriesByCategory($currentuid, $cat_id, $user_id, $start, $perPage, 'DESC', $useroffset);
+}else{
+	$weblog_result =& $weblog->getEntriesForArchives($currentuid , $user_id , $date , $cat_id , $start , $perPage , 'DESC' , $useroffset ) ;
+}
 $catresult =& $weblogcat->getCategoriesByParent($cat_id);
 
 // Include the page header
-include(XOOPS_ROOT_PATH.'/header.php');
+include_once(XOOPS_ROOT_PATH.'/header.php');
 
 // Category navigation
-$catcount = 1;
-foreach($catresult as $cat) {
-    $category = array();
-    $category['cat_title'] = $cat->getVar('cat_title', 's');
-    $category['cat_url'] = sprintf('%s/modules/%s/index.php?user_id=%d&cat_id=%d',
-                                   XOOPS_URL, $xoopsModule->dirname(),
-                                   $user_id, $cat->getVar('cat_id'));
-    $category['total'] = getAllChildrenCount($currentuid, $cat->getVar('cat_id'), $user_id);
-    $subarr = $weblogcat->getFirstChildren($cat->getVar('cat_id'));
-    $subcats = '';
-    for($i=0; $i<count($subarr); $i++) {
-        if ($i>4) {
-            $subcats .= '...';
-            break;
-        }
-        $chtitle = $subarr[$i]->getVar('cat_title', 's');
-        $subcats .= sprintf(', <a href=\'%s/modules/%s/index.php?user_id=%d&cat_id=%d\'>%s</a>',
-                           XOOPS_URL, $xoopsModule->dirname(), $user_id,
-                           $subarr[$i]->getVar('cat_id'), $chtitle);
-    }
-    $category['subs'] = substr($subcats, 2);
-    $category['count'] = $catcount++;
-    $xoopsTpl->append('categories', $category);
+if( $xoopsModuleConfig['show_category_list'] ){
+	$category_navi = array() ;
+	$cat_array = $weblogcat->getChildTreeArray(0, 'cat_title');
+	$cat_root_num = 0 ;	// flag for </tr>
+	foreach ( $cat_array as $cat ) {
+		$category = array();
+		$category['cat_id'] = $cat['cat_id'];
+		$category['cat_title'] = $myts->makeTboxData4Show($cat['cat_title']);
+		$category['count'] = $weblog->getCountByCategory($currentuid, $cat['cat_id'], $user_id);
+		$prefix_num = intval(strlen($cat['prefix']));
+		$category['prefix_num'] = $prefix_num ;	// flag for </td>
+		if( $prefix_num == 1 ){
+			$category['cat_root_num'] = $cat_root_num ;
+			$cat_root_num++ ;
+			$category['margin'] = "8px 4px 0px 0px" ;
+		}elseif( $prefix_num == 2 ){
+			$category['margin'] = "4px 4px 0px 0px" ;
+		}else{
+			$category['margin'] = "0px 0px 0px 4px" ;
+		}
+		$prefix_space = "" ;
+		$now = ($cat_id == $cat['cat_id'])? "_now" : "" ;
+		if( $prefix_num <= 3 ){
+			$category['prefix'] = sprintf("<img src='%s/modules/%s/images/cat%d%s.gif'>" , XOOPS_URL , $mydirname , $prefix_num , $now) ;
+		}else{
+			for( $i=3; $i<$prefix_num; $i++ ){
+				$prefix_space .= sprintf("<img src='%s/modules/%s/images/cat_space.gif'>" , XOOPS_URL , $mydirname )  ;
+			}
+				$category['prefix'] = $prefix_space . sprintf("<img src='%s/modules/%s/images/cat%d%s.gif'>" , XOOPS_URL , $mydirname , '3' , $now ) ;
+		}
+		$category_navi[] = $category;
+	}
+	$xoopsTpl->assign('category_col', $xoopsModuleConfig['category_col']);
+	$xoopsTpl->assign('category_navi', $category_navi);
 }
+$xoopsTpl->assign('show_category_list', $xoopsModuleConfig['show_category_list']);
+
 
 // add page navigator if # of entries bigger than # per page
 $totalPages = ceil($count / $perPage);
@@ -128,20 +158,26 @@ if ( $count > $perPage ) {
   if ($user_id>0) {
     $uri .= 'user_id='.$user_id;
   }
+  if ($date>0) {
+    if (strlen($uri)>0) {
+      $uri .= '&';
+    }
+    $uri .= 'date='.$date;
+  }
   if ($cat_id>0) {
     if (strlen($uri)>0) {
       $uri .= '&';
     }
     $uri .= 'cat_id='.$cat_id;
   }
-  include XOOPS_ROOT_PATH.'/class/pagenav.php';
+  include_once XOOPS_ROOT_PATH.'/class/pagenav.php';
   $nav = new XoopsPageNav($count, $perPage, $start, "start", $uri);
   $xoopsTpl->assign('pagination', $nav->renderNav());
 } else {
   $xoopsTpl->assign('pagination', '');
 }
 
-foreach ($result as $entryObject) {
+foreach ($weblog_result as $entryObject) {
   $entry = array();
   if ($updateReads==true) {
     $curtime = time();
@@ -160,23 +196,7 @@ foreach ($result as $entryObject) {
     setcookie(WEBLOG_COOKIE_READ, serialize($weblog_read), $curtime+$xoopsModuleConfig['expiration'], $weblogCookie['path'], $weblogCookie['domain'], $weblogCookie['secure']);
     // wellwine for cookie ends
   }
-  // member or not change entry text
-  if( $currentuid || ! isset($xoopsModuleConfig['use_memberonly']) ||  ! $xoopsModuleConfig['use_memberonly'] ){
-      $entry['contents'] = str_replace( MEMBER_ONLY_READ_DELIMETER , "" , $entryObject->getVar('contents', 's') ) ;
-  }else{
-      $entry['contents'] = preg_replace("/(". MEMBER_ONLY_READ_DELIMETER . ").*$/m" , 
-                                     "<br /><br /><a href='" . XOOPS_URL . WEBLOG_REGISTER_LEADING_PAGE . "'>" ._BL_MEMBER_ONLY_READ_MORE . "</a><br />\n" ,
-                                     $entryObject->getVar('contents', 's') ) ;
-  }
-  // entry division separator
-    if( isset($xoopsModuleConfig['use_separator']) && $xoopsModuleConfig['use_separator'] ){
-		$weblog_division_next_string = sprintf( "<br /><br /><a href=\"%s/modules/%s/details.php?blog_id=%d\">%s</a><br />\n" , 
-		                                                                  XOOPS_URL , $xoopsModule->dirname() , $entryObject->getVar('blog_id') , _BL_ENTRY_SEPARATOR_NEXT );
-        $entry['contents'] = preg_replace("/(". _BL_ENTRY_SEPARATOR_DELIMETER . ").*$/m" , 
-                                     $weblog_division_next_string , $entry['contents'] ) ;
-    }else{
-        $entry['contents'] = str_replace( _BL_ENTRY_SEPARATOR_DELIMETER , "" , $entry['contents'] ) ;
-    }
+
   // create rdf 
   include_once(sprintf('%s/modules/%s/include/PEAR/Net/TrackBack.php', XOOPS_ROOT_PATH , $xoopsModule->dirname()));
   $weblog_trackback_url = XOOPS_URL.'/modules/'.$xoopsModule->dirname().'/weblog-tb.php/'. $entryObject->getVar('blog_id')  ;
@@ -191,7 +211,7 @@ foreach ($result as $entryObject) {
     'ping'=> $weblog_trackback_url ,
     'title'=> addslashes($entryObject->getVar('title')) ,
     'identifier'=> sprintf('%s/modules/%s/details.php?blog_id=%d', XOOPS_URL , $xoopsModule->dirname() , $entryObject->getVar('blog_id') ),
-    'description'=> strip_tags(addslashes(xoops_substr( $entry['contents'] , 0 , WEBLOG_RDF_DESCRIPTION_NUM ) ) ),
+    'description'=> strip_tags(addslashes(xoops_substr( $entryObject->getvar('contents','s') , 0 , WEBLOG_RDF_DESCRIPTION_NUM ) ) ),
     'creator'=> $entryObject->getVar('uname'),
     'date'=> date("Y-m-d\TH:i:s" , $entryObject->getVar('created')) . $TZ
   ) ;
@@ -218,6 +238,7 @@ foreach ($result as $entryObject) {
   $entry['uid'] = $entryObject->getVar('user_id');
   $entry['uname'] = $entryObject->getVar('uname');
   $entry['title'] = $entryObject->getVar('title');
+  $entry['contents'] = $entryObject->getVar('contents','s' , $entryObject->getVar('blog_id') , "index");
   $path = $weblogcat->getNicePathFromId($entryObject->getVar('cat_id'),
                                         sprintf('%s/modules/%s/index.php?user_id=%d',
                                                 XOOPS_URL, $xoopsModule->dirname(),
@@ -236,8 +257,9 @@ foreach ($result as $entryObject) {
   $entry['private'] = _BL_PRIVATE;
   $entry['read_users_blog'] = sprintf('<a href="index.php?user_id=%d">%s</a>',
                                       $entryObject->getVar('user_id'), sprintf(_BL_READ_USERS_BLOG, $entryObject->getVar('uname')));
-  $priv =& xoops_getmodulehandler('priv');
-  $entry['provide_edit_link'] = ($isAdmin || ($currentuid==$entryObject->getVar('user_id') && $priv->hasPrivilege($currentUser)))?1:0;
+//  $priv =& xoops_getmodulehandler('priv');
+//  $entry['provide_edit_link'] = ($isAdmin || ($currentuid==$entryObject->getVar('user_id') && $priv->hasPrivilege($currentUser)))?1:0;
+  $entry['provide_edit_link'] = ($isAdmin || ($currentuid==$entryObject->getVar('user_id') && checkprivilege("edit",$xoopsModule->dirname())))?1:0;
   $entry['lang_reads'] = _BL_NUMBER_OF_READS;
   $entry['reads'] = $entryObject->getVar('reads');
   $entry['trackbacks'] = $entryObject->getVar('trackbacks');
@@ -262,6 +284,7 @@ $xoopsTpl->assign('rss_show', $xoopsModuleConfig['rssshow']);
 
 $xoopsTpl->assign('page_title', $xoopsModule->name());
 $xoopsTpl->assign('page_subtitle', $page_subtitle);
+$xoopsTpl->assign('xoops_weblogdir', $xoopsModule->dirname());
 //$xoopsTpl->assign('uri', $_SERVER['QUERY_STRING']);
 
 // Language assigns
@@ -282,5 +305,5 @@ $weblog_head .= sprintf('<link rel="alternate" type="application/rdf+xml" title=
 $xoopsTpl->assign('xoops_module_header', $weblog_head , $user_id );
 
 // Include the page footer
-include(XOOPS_ROOT_PATH.'/footer.php');
+include_once(XOOPS_ROOT_PATH.'/footer.php');
 ?>
