@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: blocks.php,v 1.5 2005/03/31 17:12:21 tohokuaiki Exp $
+ * $Id: blocks.php,v 1.6 2005/05/06 18:53:29 tohokuaiki Exp $
  * Copyright (c) 2003 by Jeremy N. Cowgar <jc@cowgar.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,6 +22,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
  */
+if( defined( 'FOR_XOOPS_LANG_CHECKER' ) || ! defined( 'WEBLOG_MB_LOADED' ) ) {
+
+define( 'WEBLOG_MB_LOADED' , 1 ) ;
 
 define('_MB_RECENT_EDIT_NUMBER_OF_ENTRIES','Nombre d\'articles &agrave; afficher');
 define('_MB_WEBLOG_EDIT_LINK_TO_LIST', 'Link authors to their entries? (0=No,1=Yes)'); //eng
@@ -40,4 +43,6 @@ define('_MB_WEBLOG_LANG_MOREWEBLOGS', 'More weBLogs'); // eng
 
 define('_MB_WEBLOG_USERS_SORT_READS', 'Total Reads'); // eng
 define('_MB_WEBLOG_USERS_SORT_UPDATE', 'Last Entry'); // eng
+
+}
 ?>
