@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: post.php,v 1.14 2005/04/12 15:13:54 tohokuaiki Exp $
+ * $Id: post.php,v 1.21 2005/11/07 07:32:58 tohokuaiki Exp $
  * Copyright (c) 2003 by Hiro SAKAI <http://wellwine.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -35,19 +35,38 @@ $weblogcat =& WeblogCategories::getInstance();
 $tb_operator =& Weblog_Trackback_Operator::getInstance() ;
 
 function &getEntry($post) {
+    global $xoopsModuleConfig ;
+
     $weblog =& Weblog::getInstance();
 
+    $permission_group = "" ;
+    if( isset($post['permission_group']) && is_array($post['permission_group']) ){
+        $permission_group = '|' . implode("|" , $post['permission_group']) . '|' ; 
+    }else{
+        $permission_group = ( isset($post['permission_group']) ) ? $post['permission_group'] : "" ;
+    }
+
     $entry = $weblog->newInstance();
     $entry->setVar('blog_id', $post['blog_id']);
     $entry->setVar('user_id', $post['user_id']);
     $entry->setVar('cat_id', $post['cat_id']);
+    $entry->setVar('created', $post['created']);
     $entry->setVar('title', $post['title']);
     if( isset($post['ent_trackbackurl']) )
       $entry->setVar('ent_trackbackurl', $post['ent_trackbackurl']);
     $entry->setVar('contents', $post['contents']);
-    $entry->setVar('dohtml', empty($post['dohtml']) ? 1 : 0);
     $entry->setVar('private', ! empty($post['private']) ? 'Y' : 'N');
+    $entry->setVar('permission_group', $permission_group);
     $entry->setVar('updateping', ! empty($post['updateping']) ? 1 : 0);
+    $entry->setVar('specify_created', ! empty($post['specify_created']) ? 1 : 0);
+    // dohtml check 
+    if( $xoopsModuleConfig['disable_html'] ){
+        $entry->setVar('dohtml', 0);
+        $entry->setVar('dobr', 1);
+    }else{
+        $entry->setVar('dohtml', empty($post['dohtml']) ? 1 : 0);
+        $entry->setVar('dobr', empty($post['dobr']) ? 0 : 1);
+    }
     return $entry;
 }
 
@@ -93,14 +112,19 @@ if (is_object($xoopsUser)) {
 $isAdmin = $currentUser->isAdmin($xoopsModule->mid());
 $currentuid = $currentUser->getVar('uid');
 
-// Check to ensure this user can post.
-$priv =& xoops_getmodulehandler('priv');
-if ($currentuid==0 || (!$isAdmin && ($xoopsModuleConfig['adminonly'] || !$priv->hasPrivilege($currentUser)))) {
+// Check to ensure this user can post. Anonymous reject. Admin always OK.
+include_once(sprintf('%s/modules/%s/include/privilege.inc.php', XOOPS_ROOT_PATH, $xoopsModule->dirname())) ;
+if( !$isAdmin && (! $currentuid || ! checkprivilege( "edit" , $xoopsModule->dirname() ) ) ){
     redirect_header(sprintf('%s/modules/%s/index.php', XOOPS_URL, $xoopsModule->dirname()),
                     5, _BL_ANON_CANNOT_POST_SORRY);
     exit();
 }
 
+// change specify date to created time.
+$offset = ( get_class($xoopsUser) == "xoopsuser" ) ? $xoopsUser->timezone() - $xoopsConfig['server_TZ'] : 0 ;
+if( isset($_POST['created_date']['date']) && is_array($_POST['created_date'])){
+    $_POST['created'] = strtotime($_POST['created_date']['date']) + $_POST['created_date']['time'] - ( $offset * 3600 );
+}
 // Save the post
 if (!empty($_POST['post'])) {
   if ( ! $xoopsGTicket->check() ) {
@@ -113,12 +137,16 @@ if (!empty($_POST['post'])) {
     weblog_confirm(array('blog_id'=>$entry->getVar('blog_id'),
                          'private'=>$entry->isPrivate(),
                          'dohtml'=>!$entry->doHtml(),
+                         'dobr'=>$entry->doBr(),
                          'updateping'=>$entry->isUpdateping(),
+                         'specify_created'=>$entry->isSpecifycreated(),
                          'user_id'=>$entry->getVar('user_id'),
                          'cat_id'=>$entry->getVar('cat_id'),
+                         'created'=>$entry->getVar('created'),
                          'title'=>$entry->getVar('title', 'f'),
                          'contents'=>$entry->getVar('contents', 'f'),
                          'ent_trackbackurl'=>$entry->getVar('ent_trackbackurl'),
+                         'permission_group'=>$entry->getVar('permission_group'),
                          'XOOPS_G_TICKET' => $xoopsGTicket->issue( __LINE__ ) ,
                          'continue'=>1),
                    'post.php',
@@ -142,12 +170,16 @@ if (!empty($_POST['post'])) {
     if ($isEditable) {
       $e_entry->setVar('title', $entry->getVar('title', 'n'));
       $e_entry->setVar('cat_id', $entry->getVar('cat_id'));
+      $e_entry->setVar('created', $entry->getVar('created'));
       $e_entry->setVar('contents', $entry->getVar('contents', 'n'));
       $e_entry->setVar('ent_trackbackurl', $entry->getVar('ent_trackbackurl' , 'n'));
       $e_entry->setVar('private', $entry->getVar('private', 'n'));
       $e_entry->setVar('dohtml', $entry->getVar('dohtml'));
+      $e_entry->setVar('dobr', $entry->getVar('dobr'));
       $e_entry->setVar('updateping', $entry->getVar('updateping'));
-      $ret = $weblog->saveEntry($e_entry);
+      $e_entry->setVar('specify_created', $entry->getVar('specify_created'));
+      $e_entry->setVar('permission_group', $entry->getVar('permission_group'));
+     $ret = $weblog->saveEntry($e_entry);
       if ($ret) {
           $goodPost = true;
       } else {
@@ -158,7 +190,7 @@ if (!empty($_POST['post'])) {
     }
     $pageUri .= $entry->getVar('blog_id');
   } else {
-    $entry->setVar('created', time());
+//    $entry->setVar('created', time());    // comment out as change created function added
     $old_trackbackurl = "" ;
     $entry->setVar('user_id', $currentuid);
     $ret = $weblog->saveEntry($entry);
@@ -187,7 +219,10 @@ if (!empty($_POST['post'])) {
     // trackback post
     $trackback_result_msg = "" ;
     if( trim($entry->getVar('ent_trackbackurl' , 'n')) || $old_trackbackurl ){
-        $blog_name = $xoopsModule->name() . " - " . sprintf(_BL_WHOS_BLOG,$xoopsUser->getVar('uname','E')) . " - " . $xoopsConfig['sitename'] ;
+//        $blog_name = $xoopsModule->name() . " - " . sprintf(_BL_WHOS_BLOG,$xoopsUser->getVar('uname','E')) . " - " . $xoopsConfig['sitename'] ;
+        $before_bn = array('{MODULE_NAME}','{USER_NAME}','{SITE_NAME}') ;
+        $after_bn = array($xoopsModule->name(), $xoopsUser->getVar('uname','E'), $xoopsConfig['sitename']) ;
+        $blog_name = str_replace($before_bn, $after_bn, $xoopsModuleConfig['transmit_blogname']) ;
         $blog_url = sprintf('%s/modules/%s/details.php?blog_id=%d', XOOPS_URL, $xoopsModule->dirname(),$entry->getVar('blog_id')) ;
         $tb_operator->Create_Trackback_Data( $entry , $blog_name , $blog_url ) ;
         $trackback =& $tb_operator->newInstance() ;
@@ -211,17 +246,17 @@ if (!empty($_POST['post'])) {
             $trackback_result_msg =  "<br />\n---- &nbsp; Trackback &nbsp; ----\n<br />\n" . $trackback_result_msg . "<br />" ;
         }
     }
-	// trackback(recieved) delete
-	if( isset($_POST['delete_trackback']) && is_array($_POST['delete_trackback']) ){
-		$tb_del_num = 0 ;
-		foreach( $_POST['delete_trackback'] as $tb_url ){
-			if( ! empty($tb_url) && $tb_operator->removeTrackback( $entry->getVar('blog_id') , $tb_url , "recieved" ) ){
-				$tb_del_num-- ;
-			}
-		}
-		if( $tb_del_num != 0 )
-			$weblog->handler->incrementTrackbacks( $entry->getVar('blog_id') , $tb_del_num ) ;
-	}
+    // trackback(recieved) delete
+    if( isset($_POST['delete_trackback']) && is_array($_POST['delete_trackback']) ){
+        $tb_del_num = 0 ;
+        foreach( $_POST['delete_trackback'] as $tb_url ){
+            if( ! empty($tb_url) && $tb_operator->removeTrackback( $entry->getVar('blog_id') , $tb_url , "recieved" ) ){
+                $tb_del_num-- ;
+            }
+        }
+        if( $tb_del_num != 0 )
+            $weblog->handler->incrementTrackbacks( $entry->getVar('blog_id') , $tb_del_num ) ;
+    }
     // common ping
     $common_ping_result_msg = "" ;
     if( $entry->isUpdateping() ){
@@ -274,12 +309,16 @@ if (!empty($_POST['post'])) {
                         'blog_id' => $entry->getVar('blog_id'),
                         'private'=>$entry->isPrivate(),
                         'dohtml'=>!$entry->doHtml(),
+                        'dobr'=> $entry->doBr(),
                         'updateping'=>$entry->isUpdateping(),
+                        'specify_created'=>$entry->isSpecifycreated(),
                         'user_id' => $entry->getVar('user_id'),
                         'cat_id' => $entry->getVar('cat_id'),
+                        'created' => $entry->getVar('created'),
                         'title' => $entry->getVar('title', 'n'),
                         'contents' => $entry->getVar('contents', 'n'),
                         'ent_trackbackurl'=>$entry->getVar('ent_trackbackurl'),
+                        'permission_group'=>$entry->getVar('permission_group'),
                         'XOOPS_G_TICKET' => $xoopsGTicket->issue( __LINE__ ),
                         'op' => 'delete',
                         'ok' => 1),
@@ -293,15 +332,20 @@ if (!empty($_POST['post'])) {
        redirect_header(XOOPS_URL.'/',3,$xoopsGTicket->getErrors());
   }
   $blog_id=!empty($_GET['blog_id']) ? $_GET['blog_id'] : 0;
-  if ($blog_id>0 && empty($_POST['preview'])) {
-    $entry =& $weblog->getEntry($currentuid, $blog_id) ;
+  if ($blog_id>0 && empty($_POST['preview'])) {    // edit mode
+    $entry =& $weblog->getEntry( $currentuid, $blog_id, (!$isAdmin)?$currentuid:0 ) ;
+    if( empty($entry) ){
+        redirect_header(sprintf('%s/modules/%s/index.php', XOOPS_URL, $xoopsModule->dirname()),
+                    5, _BL_CANNOT_EDIT);
+        exit() ;
+    }
     $selbox = $weblogcat->getMySelectBox($entry->getVar('cat_id'));
     // add trackback data
     $tb_operator =& Weblog_Trackback_Operator::getInstance() ;
     $ent_trackback = $tb_operator->handler->getTrackbackurl_string( $blog_id , "transmit" ) ;
     $entry->setVar( 'ent_trackbackurl' , $ent_trackback );
     $recieved_trackback = $tb_operator->handler->get( $blog_id , "recieved" ) ;
-  } else if (!empty($_POST['preview']) || !empty($_POST['continue'])) {
+  } elseif (!empty($_POST['preview']) || !empty($_POST['continue'])) {    // editting mode
     $_POST['title'] = stripslashes($_POST['title']);
     $_POST['contents'] = stripslashes($_POST['contents']);
     $entry =& getEntry($_POST);
@@ -309,12 +353,13 @@ if (!empty($_POST['post'])) {
     // add trackback data
     $tb_operator =& Weblog_Trackback_Operator::getInstance() ;
     $recieved_trackback = $tb_operator->handler->get( $entry->getVar('blog_id') , "recieved" ) ;
-  } else {
+  } else {    // first post
     $entry = $weblog->newInstance();
     $entry->setVar('user_id', -1);
     $selbox = $weblogcat->getMySelectBox();
+    $entry->setVar( 'permission_group' , $xoopsModuleConfig['default_permission'] );
   }
-  $xoopsOption['template_main'] = 'weblog_post.html';
+  $xoopsOption['template_main'] = 'weblog'.$mydirnumber . '_post.html';
   include_once XOOPS_ROOT_PATH."/include/xoopscodes.php";
 
   if( isset($recieved_trackback) && is_array($recieved_trackback) && count($recieved_trackback)>0 ){
@@ -330,14 +375,20 @@ if (!empty($_POST['post'])) {
   
   // Generate our form promatically
   include_once XOOPS_ROOT_PATH."/class/xoopsformloader.php";
+  include_once(sprintf('%s/modules/%s/include/myformdatetime.php', XOOPS_ROOT_PATH, $xoopsModule->dirname())) ;
+  include_once(sprintf('%s/modules/%s/include/myformtextdateselect.php', XOOPS_ROOT_PATH, $xoopsModule->dirname())) ;
   $blog_form = new XoopsThemeForm(_BL_POST, 'blogform', "post.php");
   $blog_form->addElement(new XoopsFormHidden('user_id',$entry->getVar('user_id')));
   $blog_form->addElement(new XoopsFormHidden('blog_id',$entry->getVar('blog_id')));
   $blog_form->addElement($xoopsGTicket->getTicketXoopsForm( __LINE__ ));
+  $blog_form->addElement(new XoopsFormLabel('',sprintf(_BL_POST_TIMEOUT, $xoopsModuleConfig['GTicket_timeout'])));
   if ($xoopsModuleConfig['minentrysize'] > 0) {
     $blog_form->addElement(new XoopsFormLabel('',sprintf(_BL_POST_MUST_BE,
                                                          $xoopsModuleConfig['minentrysize'])));
   }
+  if( $xoopsModuleConfig['disable_html'] ){
+    $blog_form->addElement(new XoopsFormLabel(_BL_CAUTION_NOHTML, _BL_FORBIDDEN_HTML_TAGS));
+  }
   $blog_form->addElement(new XoopsFormText(_BL_TITLE,'title',
                                            $xoopsModuleConfig['editorwidth'],
                                            80, $entry->getVar('title', 'e')), true);
@@ -347,53 +398,69 @@ if (!empty($_POST['post'])) {
                                                     $entry->getVar('contents', 'e'),
                                                     $xoopsModuleConfig['editorheight'],
                                                     $xoopsModuleConfig['editorwidth']), true);
-	// add image manager
-	if( isset($xoopsModuleConfig['use_imagemanager']) && $xoopsModuleConfig['use_imagemanager'] ){
-		$imagemanager_valid = false ;
-		// check GD2 module extension is loaded or not.
-		if( function_exists("gd_info") ){
-			$gd_infomation = gd_info() ;
-			if( substr( $gd_infomation['GD Version'] , 0 , 10 ) == 'bundled (2' )	// GD version 2 is required
-				$imagemanager_valid = true ;
-		}
-		if( $imagemanager_valid ){
-			$imagemanager_tag = sprintf('<img onmouseover=\'style.cursor="hand"\' onclick=\'javascript:openWithSelfMain("%s/modules/%s/weblog-imagemanager.php?target=contents","imgmanager",400,430);\' src="%s/modules/%s/images/weblog_imagemanager.gif" alt="image" />' ,
+    // add image manager
+    if( isset($xoopsModuleConfig['use_imagemanager']) && $xoopsModuleConfig['use_imagemanager'] ){
+        $imagemanager_valid = false ;
+        // check GD2 module extension is loaded or not.
+        if( function_exists("gd_info") ){
+            $gd_infomation = gd_info() ;
+            if( preg_match('/2\./', $gd_infomation['GD Version']) )    // GD version 2 is required
+                $imagemanager_valid = true ;
+        }
+        if( $imagemanager_valid ){
+            $imagemanager_tag = sprintf('<img onmouseover=\'style.cursor="hand"\' onclick=\'javascript:openWithSelfMain("%s/modules/%s/weblog-imagemanager.php?target=contents","imgmanager",400,430);\' src="%s/modules/%s/images/weblog_imagemanager.gif" alt="image" />' ,
                                                             XOOPS_URL , $xoopsModule->dirname() , XOOPS_URL , $xoopsModule->dirname() );
-		}else{
-			$imagemanager_tag = _BL_WEBLOG_IMAGEMANAGER_CAUTION ;
-		}
-		$imagemanager_tray = new XoopsFormElementTray( _BL_WEBLOG_IMAGEMANAGER ,'');
-		$imagemanager_button = new XoopsFormLabel('' , $imagemanager_tag ) ;
-		$imagemanager_tray->addElement($imagemanager_button) ;
-	    $blog_form->addElement($imagemanager_tray) ;
-	}
-	// add devide entry separator
-	if( isset($xoopsModuleConfig['use_separator']) && $xoopsModuleConfig['use_separator'] ){
-	    $separator_tray = new XoopsFormElementTray( _BL_ENTRY_SEPARATOR ,'');
-		$separator_button = new XoopsFormButton(_BL_ENTRY_SEPARATOR_CAPTION . "<br />" , '' , _BL_ENTRY_SEPARATOR_VALUE , 'button') ;
-		$separator_button->setExtra("onclick='xoopsCodeSmilie(\"contents\", \"\\n" . _BL_ENTRY_SEPARATOR_DELIMETER . "\\n\");'") ;
-		$separator_tray->addElement($separator_button) ;
-	    $blog_form->addElement($separator_tray) ;
-	}
-	// add member only javascript
-	if( isset($xoopsModuleConfig['use_memberonly']) && $xoopsModuleConfig['use_memberonly'] ){
-	    $membershow_tray = new XoopsFormElementTray( _BL_MEMBER_ONLY_READ ,'');
-		$membershow_button = new XoopsFormButton(_BL_MEMBER_ONLY_READ_CAPTION . "<br />" , '' , _BL_MEMBER_ONLY_READ_VALUE , 'button') ;
-		$membershow_button->setExtra("onclick='xoopsCodeSmilie(\"contents\", \"\\n" . MEMBER_ONLY_READ_DELIMETER . "\\n\");'") ;
-		$membershow_tray->addElement($membershow_button) ;
-	    $blog_form->addElement($membershow_tray) ;
-	}
+        }else{
+            $imagemanager_tag = _BL_WEBLOG_IMAGEMANAGER_CAUTION ;
+        }
+        $imagemanager_tray = new XoopsFormElementTray( _BL_WEBLOG_IMAGEMANAGER ,'');
+        $imagemanager_button = new XoopsFormLabel('' , $imagemanager_tag ) ;
+        $imagemanager_tray->addElement($imagemanager_button) ;
+        $blog_form->addElement($imagemanager_tray) ;
+        // one click image upload
+//        if( $imagemanager_valid ){
+//            $oneclick_im_tray = new XoopsFormElementTray("one click IM" ,'') ;
+//            $oneclick_im_tray->addElement(new XoopsFormFile("you can post image file at ease.<br />" , 'oneclick_image_file', 5000000)) ;
+///            $blog_form->addElement($oneclick_im_tray) ;
+//        }
+    }
+    // add devide entry separator
+    if( isset($xoopsModuleConfig['use_separator']) && $xoopsModuleConfig['use_separator'] ){
+        $separator_tray = new XoopsFormElementTray( _BL_ENTRY_SEPARATOR ,'');
+        $separator_button = new XoopsFormButton(_BL_ENTRY_SEPARATOR_CAPTION . "<br />" , '' , _BL_ENTRY_SEPARATOR_VALUE , 'button') ;
+        $separator_button->setExtra("onclick='xoopsCodeSmilie(\"contents\", \"\\n" . _BL_ENTRY_SEPARATOR_DELIMETER . "\\n\");'") ;
+        $separator_tray->addElement($separator_button) ;
+        $blog_form->addElement($separator_tray) ;
+    }
+    // add member only javascript
+    if( isset($xoopsModuleConfig['use_memberonly']) && $xoopsModuleConfig['use_memberonly'] ){
+        $membershow_tray = new XoopsFormElementTray( _BL_MEMBER_ONLY_READ ,'');
+        $membershow_button = new XoopsFormButton(_BL_MEMBER_ONLY_READ_CAPTION . "<br />" , '' , _BL_MEMBER_ONLY_READ_VALUE , 'button') ;
+        $membershow_button->setExtra("onclick='xoopsCodeSmilie(\"contents\", \"\\n" . MEMBER_ONLY_READ_DELIMETER . "\\n\");'") ;
+        $membershow_tray->addElement($membershow_button) ;
+        $blog_form->addElement($membershow_tray) ;
+    }
     // options check box
     $checkbox_tray = new XoopsFormElementTray(_BL_OPTIONS ,'<br />');
-    $checkbox_dohtml = new XoopsFormCheckBox('', 'dohtml', !$entry->doHtml());
-    $checkbox_dohtml->addOption('dohtml', _BL_DISABLEHTML);
-    $checkbox_tray->addElement($checkbox_dohtml);
+    if( ! $xoopsModuleConfig['disable_html'] ){
+        $checkbox_dohtml = new XoopsFormCheckBox('', 'dohtml', !$entry->doHtml());
+        $checkbox_dohtml->addOption('dohtml', _BL_DISABLEHTML);
+            $checkbox_tray->addElement($checkbox_dohtml);
+        $checkbox_dobr = new XoopsFormCheckBox('', 'dobr', $entry->doBr());
+        $checkbox_dobr->addOption('dobr', _BL_WRAPLINES);
+            $checkbox_tray->addElement($checkbox_dobr);
+    }
     $checkbox_private = new XoopsFormCheckBox('', 'private', $entry->isPrivate());
     $checkbox_private->addOption('private', _BL_PRIVATE);
-    $checkbox_tray->addElement($checkbox_private);
+        $checkbox_tray->addElement($checkbox_private);
     $checkbox_updateping = new XoopsFormCheckBox('', 'updateping', $entry->isUpdateping());
     $checkbox_updateping->addOption('updateping', _BL_UPDATEPING );
-   $checkbox_tray->addElement($checkbox_updateping);
+        $checkbox_tray->addElement($checkbox_updateping);
+    $checkbox_published = new XoopsFormCheckBox('', 'specify_created', $entry->isSpecifycreated());
+    $checkbox_published->addOption('specify_created', _BL_SPECIFY_TIME );
+        $checkbox_tray->addElement($checkbox_published);
+    $checkbox_publish = new myXoopsFormDateTime(_BL_SPECIFY_TIME_DSC, 'created_date', 15, $entry->getVar('created')) ;
+        $checkbox_tray->addElement($checkbox_publish);
     $blog_form->addElement($checkbox_tray);
     // trackback url textbox
     $trackback_tray = new XoopsFormElementTray(_BL_TRACKBACK, '<br />') ;
@@ -410,13 +477,40 @@ if (!empty($_POST['post'])) {
         foreach( $recieved_trackback as $key=>$tb_obj ){
             $checked = ( isset($_POST['delete_trackback'][$key]) ) ? true : false ;
             $recieved_trackback =& new XoopsFormCheckBox(_BL_TRACKBACK_DELETE, "delete_trackback[$key]", $checked );
-            $recieved_trackback->addOption($tb_obj->getVar('tb_url'), xoops_substr($tb_obj->getVar('title','n') . ':' . $tb_obj->getVar('description','n'),0,60) . "..." );
+            $recieved_trackback->addOption($tb_obj->getVar('tb_url'), htmlspecialchars(xoops_substr($tb_obj->getVar('title','n') . ':' . $tb_obj->getVar('description','n'),0,60) . "..." ));
             $recieved_trackback_tray->addElement($recieved_trackback);
         }
         $blog_form->addElement($recieved_trackback_tray);
     }
-
-
+  // permission control
+  if( isset($xoopsModuleConfig['use_permissionsystem']) && $xoopsModuleConfig['use_permissionsystem'] ){
+    $permission_tray = new XoopsFormElementTray( _BL_PERMISSION , '<br />');
+//  $permission_tab = new XoopsFormSelect('Please set read permission of this Entry.<br />L to R :Your group\'s, Other group\'s and Anonymous users\'. "r" means readable.<br />', "permission" , $entry->getVar('permission') ) ;
+//  $permission_tab->addOptionArray( array('111'=>'r-r-r' , '110'=>'r-r--' , '100'=>'r----' , '010'=>'--r--') ) ;  
+    $member_handler =& xoops_gethandler('group');
+    $groups =& $member_handler->getObjects();
+    $group_option = array() ;
+    $group_array = array() ;
+    foreach( $groups as $group ){
+           if( $group->getVar('groupid') == 1 ) continue ;
+        $group_option[$group->getVar('groupid')] = $group->getVar('name') ;
+        $group_array[] = $group->getVar('groupid') ;
+    }
+    if( is_array($entry->getVar('permission_group','n')) ){
+       $default_permission = $entry->getVar('permission_group','n') ;
+    }else{
+       if( $entry->getVar('permission_group','n') == "all" ){
+           $default_permission = $group_array ;
+       }else{
+           $default_permission = explode('|',$entry->getVar('permission_group','n')) ;
+       }
+    }
+    $permission_tab = new XoopsFormSelect(_BL_PERMISSION_CAPTION."<br />" , "permission_group" , $default_permission , 4 , true ) ;
+    $permission_tab->addOptionArray($group_option) ;
+    $permission_tray->addElement($permission_tab) ;
+    $blog_form->addElement($permission_tray);
+  }
+ 
   $button_tray = new XoopsFormElementTray('' ,'');
   if ($entry->getVar('blog_id') > 0 && $isAdmin || $currentuid == $entry->getVar('user_id')) {
     $button_tray->addElement(new XoopsFormButton('','delete', _BL_DELETE_BUTTON, 'submit'));
@@ -436,15 +530,15 @@ if (!empty($_POST['post'])) {
       if (!empty($avatar) && $avatar != 'blank.gif') {
         $use_avatar = 1;
         $avatar_img = sprintf('%s/uploads/%s', XOOPS_URL, $avatar);
-        $dimension = ( ini_get('allow_url_fopen') ) ? getimagesize($avatar_img) : "" ;;
-        $avatar_width = $dimension[0];
+//        $dimension = ( ini_get('allow_url_fopen') ) ? getimagesize($avatar_img) : "" ;
+//        $avatar_width = ( is_array($dimension) ) ? $dimension[0] : "" ;
       }
     }
 
+    $xoopsTpl->assign('preview', $entry->getVar('contents', 's'));
     $xoopsTpl->assign('use_avatar', $use_avatar);
     $xoopsTpl->assign('avatar_width', $avatar_width);
     $xoopsTpl->assign('avatar_img', $avatar_img);
-    $xoopsTpl->assign('preview', $entry->getVar('contents', 's'));
     $xoopsTpl->assign('title', $entry->getVar('title', 's'));
     $xoopsTpl->assign('is_preview',1);
     $xoopsTpl->assign('sample_date', formatTimestamp(time(),
